@@ -37,7 +37,7 @@ __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_AS7341.git"
 
 from time import sleep, monotonic
 from micropython import const
-import adafruit_bus_device.i2c_device as i2c_device
+from adafruit_bus_device import i2c_device
 
 from adafruit_register.i2c_struct import UnaryStruct, Struct  # , ROUnaryStruct
 from adafruit_register.i2c_bit import RWBit
